@@ -65,34 +65,34 @@
 #'
 #' @examples
 #' # Generate synthetic data for this example
-#' data <- GenSynthetic(n=500,p=1000,k=10,seed=1)
+#' data <- GenSynthetic(n=100,p=20,k=10,seed=1)
 #' X = data$X
 #' y = data$y
 #'
-#' # Fit an L0 regression model with a maximum of 50 non-zeros using coordinate descent (CD)
-#' fit1 <- L0Learn.fit(X, y, penalty="L0", maxSuppSize=50)
+#' # Fit an L0 regression model with a maximum of 20 non-zeros using coordinate descent (CD)
+#' fit1 <- L0Learn.fit(X, y, penalty="L0", maxSuppSize=20)
 #' print(fit1)
-#' # Extract the coefficients at lambda = 0.0325142
-#' coef(fit1, lambda=0.0325142)
+#' # Extract the coefficients at lambda = 2.28552e-02
+#' coef(fit1, lambda=2.28552e-02)
 #' # Apply the fitted model on X to predict the response
-#' predict(fit1, newx = X, lambda=0.0325142)
+#' predict(fit1, newx = X, lambda=2.28552e-02)
 #'
-#' # Fit an L0 regression model with a maximum of 50 non-zeros using CD and local search
-#' fit2 <- L0Learn.fit(X, y, penalty="L0", algorithm="CDPSI", maxSuppSize=50)
+#' # Fit an L0 regression model with a maximum of 20 non-zeros using CD and local search
+#' fit2 <- L0Learn.fit(X, y, penalty="L0", algorithm="CDPSI", maxSuppSize=20)
 #' print(fit2)
 #'
-#' # Fit an L0L2 regression model with 10 values of Gamma ranging from 0.0001 to 10, using CD
-#' fit3 <- L0Learn.fit(X, y, penalty="L0L2", maxSuppSize=50, nGamma=10, gammaMin=0.0001, gammaMax = 10)
+#' # Fit an L0L2 regression model with 3 values of Gamma ranging from 0.0001 to 10, using CD
+#' fit3 <- L0Learn.fit(X, y, penalty="L0L2", maxSuppSize=20, nGamma=3, gammaMin=0.0001, gammaMax = 10)
 #' print(fit3)
-#' # Extract the coefficients at lambda = 0.0361829 and gamma = 0.0001
-#' coef(fit3, lambda=0.0361829, gamma=0.0001)
+#' # Extract the coefficients at lambda = 2.45513e-02 and gamma = 0.0001
+#' coef(fit3, lambda=2.45513e-02, gamma=0.0001)
 #' # Apply the fitted model on X to predict the response
-#' predict(fit3, newx = X, lambda=0.0361829, gamma=0.0001)
+#' predict(fit3, newx = X, lambda=2.45513e-02, gamma=0.0001)
 #'
 #' # Fit an L0 logistic regression model
 #' # First, convert the response to binary
 #' y = sign(y)
-#' fit4 <- L0Learn.fit(X, y, loss="Logistic", maxSuppSize=20)
+#' fit4 <- L0Learn.fit(X, y, loss="Logistic", maxSuppSize=10)
 #' print(fit4)
 #'
 #' @export
@@ -152,7 +152,7 @@ L0Learn.fit <- function(x, y, loss="SquaredError", penalty="L0", algorithm="CD",
     
     # Handle Lambda Grids:
     if (length(lambdaGrid) != 0){
-        if (!is.null(autoLambda) && !autoLambda){
+        if (!is.null(autoLambda)){
             warning("In L0Learn V2+, autoLambda is ignored and inferred if 'lambdaGrid' is supplied", call.=FALSE)
         }
         autoLambda = FALSE
@@ -285,8 +285,7 @@ L0Learn.fit <- function(x, y, loss="SquaredError", penalty="L0", algorithm="CD",
 			last = length(M$SuppSize[[i]])
 			if (M$SuppSize[[i]][last] > maxSuppSize){
 					if (last == 1){
-							print("Warning! Only 1 element in path with support size > maxSuppSize.")
-							print("Try increasing maxSuppSize to resolve the issue.")
+							warning("Warning! Only 1 element in path with support size > maxSuppSize. \n Try increasing maxSuppSize to resolve the issue.")
 					} else{
 							M$SuppSize[[i]] = M$SuppSize[[i]][-last]
 							M$Converged[[i]] = M$Converged[[i]][-last]
