@@ -1,4 +1,4 @@
-#' @importFrom stats rnorm
+#' @importFrom stats rnorm var
 #' @title Generate Synthetic Data
 #'
 #' @description Generates a synthetic dataset as follows: 1) Sample every element in data matrix X from N(0,1).
@@ -10,7 +10,8 @@
 #' @param seed The seed used for randomly generating the data
 #' @param rho The threshold for setting values to 0.  if |X(i, j)| > rho => X(i, j) <- 0
 #' @param b0 intercept value to translate y by.
-#' @param error_ratio multiplier for the magnitude of the error term 'e'.
+#' @param snr desired Signal-to-Noise ratio. This sets the magnitude of the error term 'e'. 
+#' SNR is defined as  SNR = Var(XB)/Var(e)
 #' @return A list containing:
 #'  the data matrix X,
 #'  the response vector y,
@@ -18,17 +19,23 @@
 #'  the error vector e,
 #'  the intercept term b0.
 #' @examples
-#' data <- GenSynthetic(n=500,p=1000,k=10,seed=1)
+#' data <- GenSynthetic(n=100,p=20,k=10,seed=1)
 #' X = data$X
 #' y = data$y
 #' @export
-GenSynthetic <- function(n, p, k, seed, rho=0, b0=0, error_ratio=1)
+GenSynthetic <- function(n, p, k, seed, rho=0, b0=0, snr=1)
 {
     set.seed(seed) # fix the seed to get a reproducible result
     X = matrix(rnorm(n*p),nrow=n,ncol=p)
     X[abs(X) < rho] <- 0.
     B = c(rep(1,k),rep(0,p-k))
-    e = rnorm(n)*error_ratio
+    sd_e = NULL
+    if (snr == +Inf){
+        sd_e = sqrt(var(X %*% B)/snr)
+    } else {
+        sd_e = 0
+    }
+    e = rnorm(n, sd = sd_e)
     y = X%*%B + e + b0
     list(X=X, y=y, B=B, e=e, b0=b0)
 }
