@@ -11,7 +11,7 @@ FitResult<T> CDL012Swaps<T>::_FitWithBounds() {
 
 template <class T>
 FitResult<T> CDL012Swaps<T>::_Fit() {
-    auto result = CDL012<T>(*(this->X), *(this->y), this->P).Fit(); // result will be maintained till the end
+    auto result = CDL012<T>(*(this->X), this->y, this->P).Fit(); // result will be maintained till the end
     this->B = result.B;
     this->b0 = result.b0;
     double objective = result.Objective;
@@ -30,7 +30,7 @@ FitResult<T> CDL012Swaps<T>::_Fit() {
         
         // TODO: This calculation is already preformed in a previous step
         // Can be pulled/stored 
-        arma::vec r = *(this->y) - *(this->X) * this->B - this->b0; 
+        arma::vec r = this->y - *(this->X) * this->B - this->b0; 
         
         for (auto& i : NnzIndices) {
             arma::rowvec riX = (r + this->B[i] * matrix_column_get(*(this->X), i)).t() * *(this->X); 
@@ -68,13 +68,13 @@ FitResult<T> CDL012Swaps<T>::_Fit() {
                 
                 // Change initial solution to Swapped value to seed standard CD algorithm.
                 this->P.InitialSol = &(this->B);
-                *this->P.r = *(this->y) - *(this->X) * (this->B) - this->b0;
+                *this->P.r = this->y - *(this->X) * (this->B) - this->b0;
                 // this->P already has access to b0.
                 
                 // proposed_result object.
                 // Keep tack of previous_best result object
                 // Only override previous_best if proposed_result has a better objective.
-                result = CDL012<T>(*(this->X), *(this->y), this->P).Fit();
+                result = CDL012<T>(*(this->X), this->y, this->P).Fit();
                 
                 // Rcpp::Rcout << "Swap Objective  " <<  result.Objective << " \n";
                 // Rcpp::Rcout << "Old Objective  " <<  objective << " \n";
